# 아키텍처별로 사용할 모듈을 가져옵니다.
import platform
import os
import shutil

# 복사할 .so 파일을 저장할 디렉토리 경로
destination_directory = os.getcwd()

# 현재 아키텍처를 확인합니다.
architecture = platform.machine()

if architecture == 'x86_64':
    source_directory = destination_directory + '/x86_64/'
elif architecture == 'armv7l':
    source_directory = destination_directory + '/armv7l/'
elif architecture == 'aarch64':
    source_directory = destination_directory + '/aarch64/'
else:
    raise ImportError(f"Unsupported architecture: {architecture}")




# 원본 디렉토리의 모든 파일과 폴더 목록 얻기
file_list = os.listdir(source_directory)

# .so 파일만 필터링
so_files = [file for file in file_list if file.endswith('.so')]

# .so 파일을 목적지 디렉토리로 복사
for so_file in so_files:
    source_file_path = os.path.join(source_directory, so_file)
    destination_file_path = os.path.join(destination_directory, so_file)

    try:
        shutil.copy2(source_file_path, destination_file_path)  # 파일 복사
        print(f"{so_file} 파일을 복사했습니다.")
    except Exception as e:
        print(f"{so_file} 파일 복사 중 오류 발생: {str(e)}")



from setuptools import setup, find_packages
import os
import shutil

target_directory = 'SG1AB'

setup(
    name=target_directory,
    version='1.0.2.2',
    description='nnfw_api binding',
    long_description='you can use nnfw_api by python',
    url='https://github.com/Samsung/ONE/tree/master/runtime',
    author='Your Name',
    author_email='your@email.com',
    license='Samsung',
    packages=[target_directory],
    package_data={target_directory: ['nnfw_api_pybind.cpython-38-x86_64-linux-gnu.so', 'x86_64/libnnfw-dev.so', 'x86_64/libonert_core.so', 'x86_64/libbackend_cpu.so','nnfw_api_pybind.cpython-38-arm-linux-gnueabihf.so', 'armv7l/libnnfw-dev.so', 'armv7l/libonert_core.so', 'armv7l/libbackend_cpu.so','nnfw_api_pybind.cpython-38-aarch64-linux-gnu.so', 'aarch64/libnnfw-dev.so', 'aarch64/libonert_core.so', 'aarch64/libbackend_cpu.so']},
    install_requires=[
        # 필요한 의존성 패키지를 여기에 추가
    ],
)
